utils
=====

In this module there are several utilities used by the weatherDB package, you shouldn't need to use them directly.

.. autoclass:: weatherDB.utils.TimestampPeriod

dwd
---
.. automodule:: weatherDB.utils.dwd

geometry
--------
.. automodule:: weatherDB.utils.geometry

get_data
--------
.. automodule:: weatherDB.utils.get_data

logging
-------
.. automodule:: weatherDB.utils.logging
